| Title: | Tool-Box of Chain Ladder Plus Models |
|---|---|
| Description: | Implementation of the age-period-cohort models for the claim development presented in the manuscript 'Replicating and extending chain-ladder via an age-period-cohort structure on the claim development in a run-off triangle' <doi:10.1080/10920277.2025.249672>. |
| Authors: | Gabriele Pittarello [aut, cre, cph] (ORCID: <https://orcid.org/0000-0003-3360-5826>), Munir Hiabu [aut, cph] (ORCID: <https://orcid.org/0000-0001-5846-667X>), Andres Villegas [aut, cph] |
| Maintainer: | Gabriele Pittarello <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0.1 |
| Built: | 2026-05-15 09:49:48 UTC |
| Source: | https://github.com/gpitt71/clmplus |
Pre-process Run-Off Triangles.
AggregateDataPP( cumulative.payments.triangle, entries.weights = NULL, eta = 1/2 )AggregateDataPP( cumulative.payments.triangle, entries.weights = NULL, eta = 1/2 )
cumulative.payments.triangle |
|
entries.weights |
|
eta |
|
An object of class AggregateDataPP. Lists the following elements:
cumulative.payments.triangle |
|
occurrance |
|
exposure |
|
incremental.payments.triangle |
|
fit.w |
|
J |
|
diagonal |
|
eta |
|
Pittarello, G., Hiabu, M., & Villegas, A. M. (2023). Replicating and extending chain-ladder via an age-period-cohort structure on the claim development in a run-off triangle. arXiv preprint arXiv:2301.03858.
data(sifa.mtpl) sifa.mtpl.rtt <- AggregateDataPP(cumulative.payments.triangle=sifa.mtpl)data(sifa.mtpl) sifa.mtpl.rtt <- AggregateDataPP(cumulative.payments.triangle=sifa.mtpl)
Dataset of cumulative paid claims for a small italian company in the line of business: general third party liability.
amases.gtplamases.gtpl
Run-off triangle with 12 development periods.
Savelli, Nino, and Clemente, Gian Paolo. "Lezioni di matematica attuariale delle assicurazioni danni." EDUCatt-Ente per il diritto allo studio universitario dell'Università Cattolica, 2014
Dataset of cumulative paid claims for a small italian company in the line of business: motor or damage.
amases.modamases.mod
Run-off triangle with 12 development periods.
Savelli, Nino, and Clemente, Gian Paolo. "Lezioni di matematica attuariale delle assicurazioni danni." EDUCatt-Ente per il diritto allo studio universitario dell'Università Cattolica, 2014
Dataset of cumulative paid claims for a small italian company in the line of business: motor third party liability.
amases.mtplamases.mtpl
Run-off triangle with 12 development periods.
Savelli, Nino, and Clemente, Gian Paolo. "Lezioni di matematica attuariale delle assicurazioni danni." EDUCatt-Ente per il diritto allo studio universitario dell'Università Cattolica, 2014
Method to Estimate Chain Ladder plus models.
clmplus( AggregateDataPP, hazard.model = NULL, link = c("log", "logit"), staticAgeFun = TRUE, periodAgeFun = "NP", cohortAgeFun = NULL, effect_log_scale = TRUE, constFun = function(ax, bx, kt, b0x, gc, wxt, ages) list(ax = ax, bx = bx, kt = kt, b0x = b0x, gc = gc), ... )clmplus( AggregateDataPP, hazard.model = NULL, link = c("log", "logit"), staticAgeFun = TRUE, periodAgeFun = "NP", cohortAgeFun = NULL, effect_log_scale = TRUE, constFun = function(ax, bx, kt, b0x, gc, wxt, ages) list(ax = ax, bx = bx, kt = kt, b0x = b0x, gc = gc), ... )
AggregateDataPP |
|
hazard.model |
|
link |
|
staticAgeFun |
|
periodAgeFun |
|
cohortAgeFun |
|
effect_log_scale |
|
constFun |
|
... |
parameters to be passed to clmplus. |
No return value, called to pass method clmplus.AggregateDataPP. See clmplus.AggregateDataPP documentation.
Pittarello, Gabriele, Munir Hiabu, and Andrés M. Villegas. "Replicating and extending chain ladder via an age-period-cohort structure on the claim development in a run-off triangle." arXiv preprint arXiv:2301.03858 (2023).
data(sifa.mtpl) sifa.mtpl.rtt <- AggregateDataPP(cumulative.payments.triangle=sifa.mtpl) hz.chl=clmplus(sifa.mtpl.rtt, 'a')data(sifa.mtpl) sifa.mtpl.rtt <- AggregateDataPP(cumulative.payments.triangle=sifa.mtpl) hz.chl=clmplus(sifa.mtpl.rtt, 'a')
Method to fit Chain Ladder plus models to AggregateDataPP objects.
## S3 method for class 'AggregateDataPP' clmplus( AggregateDataPP, hazard.model = NULL, link = c("log", "logit"), staticAgeFun = TRUE, periodAgeFun = "NP", cohortAgeFun = NULL, effect_log_scale = TRUE, constFun = function(ax, bx, kt, b0x, gc, wxt, ages) list(ax = ax, bx = bx, kt = kt, b0x = b0x, gc = gc), ... )## S3 method for class 'AggregateDataPP' clmplus( AggregateDataPP, hazard.model = NULL, link = c("log", "logit"), staticAgeFun = TRUE, periodAgeFun = "NP", cohortAgeFun = NULL, effect_log_scale = TRUE, constFun = function(ax, bx, kt, b0x, gc, wxt, ages) list(ax = ax, bx = bx, kt = kt, b0x = b0x, gc = gc), ... )
AggregateDataPP |
|
hazard.model |
|
link |
|
staticAgeFun |
|
periodAgeFun |
|
cohortAgeFun |
|
effect_log_scale |
|
constFun |
|
... |
parameters to be passed to clmplus. |
An object of class clmplusmodel. A list with the following elements:
model.fit |
|
apc_input |
|
hazard_scaled_deviance_residuals |
|
fitted_development_factors |
|
fitted_effects |
|
Pittarello, Gabriele, Munir Hiabu, and Andrés M. Villegas. "Replicating and extending chain ladder via an age-period-cohort structure on the claim development in a run-off triangle." arXiv preprint arXiv:2301.03858 (2023).
data(sifa.mtpl) sifa.mtpl.rtt <- AggregateDataPP(cumulative.payments.triangle=sifa.mtpl) hz.chl=clmplus(sifa.mtpl.rtt, 'a')data(sifa.mtpl) sifa.mtpl.rtt <- AggregateDataPP(cumulative.payments.triangle=sifa.mtpl) hz.chl=clmplus(sifa.mtpl.rtt, 'a')
Default method to fit Chain Ladder plus models.
## Default S3 method: clmplus( AggregateDataPP, hazard.model = NULL, link = c("log", "logit"), staticAgeFun = TRUE, periodAgeFun = "NP", cohortAgeFun = NULL, effect_log_scale = TRUE, constFun = function(ax, bx, kt, b0x, gc, wxt, ages) list(ax = ax, bx = bx, kt = kt, b0x = b0x, gc = gc), ... )## Default S3 method: clmplus( AggregateDataPP, hazard.model = NULL, link = c("log", "logit"), staticAgeFun = TRUE, periodAgeFun = "NP", cohortAgeFun = NULL, effect_log_scale = TRUE, constFun = function(ax, bx, kt, b0x, gc, wxt, ages) list(ax = ax, bx = bx, kt = kt, b0x = b0x, gc = gc), ... )
AggregateDataPP |
|
hazard.model |
|
link |
|
staticAgeFun |
|
periodAgeFun |
|
cohortAgeFun |
|
effect_log_scale |
|
constFun |
|
... |
parameters to be passed to clmplus. |
No return value, called to pass method clmplus.AggregateDataPP. See clmplus.AggregateDataPP documentation.
Pittarello, Gabriele, Munir Hiabu, and Andrés M. Villegas. "Replicating and extending chain ladder via an age-period-cohort structure on the claim development in a run-off triangle." arXiv preprint arXiv:2301.03858 (2023).
Hiabu, Munir. “On the relationship between classical chain ladder and granular reserving.” Scandinavian Actuarial Journal 2017 (2017): 708 - 729.
This function allows to define the behavior of the triangle payments.
## S3 method for class 'AggregateDataPP' plot(x, ...)## S3 method for class 'AggregateDataPP' plot(x, ...)
x |
AggregateDataPP to be plotted. |
... |
Arguments to be passed to plot. |
No return value, plots the run-off triangle cumulative payments and incremental payments.
Pittarello, Gabriele, Munir Hiabu, and Andrés M. Villegas. "Replicating and extending chain ladder via an age-period-cohort structure on the claim development in a run-off triangle." arXiv preprint arXiv:2301.03858 (2023).
data(sifa.mtpl) sifa.mtpl.pp <- AggregateDataPP(cumulative.payments.triangle=sifa.mtpl) plot(sifa.mtpl.pp)data(sifa.mtpl) sifa.mtpl.pp <- AggregateDataPP(cumulative.payments.triangle=sifa.mtpl) plot(sifa.mtpl.pp)
This function allows to plot the hazard model residuals on the triangle payments.
## S3 method for class 'clmplusmodel' plot(x, heat.lim = c(-2.5, 2.5), ...)## S3 method for class 'clmplusmodel' plot(x, heat.lim = c(-2.5, 2.5), ...)
x |
|
heat.lim |
limits in the residuals plot. |
... |
Extra arguments to be passed to the plot function. |
No return value, plots the hazard model residuals in triangular form.
Pittarello, Gabriele, Munir Hiabu, and Andrés M. Villegas. "Replicating and extending chain ladder via an age-period-cohort structure on the claim development in a run-off triangle." arXiv preprint arXiv:2301.03858 (2023).
data(sifa.mtpl) sifa.mtpl.rtt <- AggregateDataPP(cumulative.payments.triangle=sifa.mtpl) clm.fit<-clmplus(sifa.mtpl.rtt, 'a') plot(clm.fit)data(sifa.mtpl) sifa.mtpl.rtt <- AggregateDataPP(cumulative.payments.triangle=sifa.mtpl) clm.fit<-clmplus(sifa.mtpl.rtt, 'a') plot(clm.fit)
This function allows to define the behavior of the triangle payments.
## S3 method for class 'clmpluspredictions' plot(x, cy.type = "fe", ...)## S3 method for class 'clmpluspredictions' plot(x, cy.type = "fe", ...)
x |
|
cy.type |
|
... |
Arguments to be passed to plot. |
No return value, plots coefficients of the hazard models.
Pittarello, G., Hiabu, M., & Villegas, A. M. (2023). Replicating and extending chain-ladder via an age-period-cohort structure on the claim development in a run-off triangle. arXiv preprint arXiv:2301.03858.
data(sifa.mtpl) sifa.mtpl.rtt <- AggregateDataPP(cumulative.payments.triangle=sifa.mtpl) clm.fit<-clmplus(sifa.mtpl.rtt, 'a') clm <- predict(clm.fit) plot(clm)data(sifa.mtpl) sifa.mtpl.rtt <- AggregateDataPP(cumulative.payments.triangle=sifa.mtpl) clm.fit<-clmplus(sifa.mtpl.rtt, 'a') clm <- predict(clm.fit) plot(clm)
Predict the lower triangle with a clmplus model.
## S3 method for class 'clmplusmodel' predict( object, gk.fc.model = "a", ckj.fc.model = "a", gk.order = c(1, 1, 0), ckj.order = c(0, 1, 0), forecasting_horizon = NULL, constrained_development_factors = FALSE, ... )## S3 method for class 'clmplusmodel' predict( object, gk.fc.model = "a", ckj.fc.model = "a", gk.order = c(1, 1, 0), ckj.order = c(0, 1, 0), forecasting_horizon = NULL, constrained_development_factors = FALSE, ... )
object |
|
gk.fc.model |
|
ckj.fc.model |
|
gk.order |
|
ckj.order |
|
forecasting_horizon |
|
... |
Extra arguments to be passed to the predict function. |
constrained_development_factor |
|
Returns the following output:
reserve |
|
ultimate_cost |
|
full_triangle |
|
lower_triangle |
|
development_factors_predicted |
|
apc_output |
|
Pittarello, Gabriele, Munir Hiabu, and Andrés M. Villegas. "Replicating and extending chain ladder via an age-period-cohort structure on the claim development in a run-off triangle." arXiv preprint arXiv:2301.03858 (2023).
Dataset of cumulative paid claims for a medium italian company in the line of business: general third party liability.
sifa.gtplsifa.gtpl
Run-off triangle with 12 development periods.
Savelli, Nino, and Clemente, Gian Paolo. "Lezioni di matematica attuariale delle assicurazioni danni." EDUCatt-Ente per il diritto allo studio universitario dell'Università Cattolica, 2014
Dataset of cumulative paid claims for a medium italian company in the line of business: motor or damage.
sifa.modsifa.mod
Run-off triangle with 12 development periods.
Savelli, Nino, and Clemente, Gian Paolo. "Lezioni di matematica attuariale delle assicurazioni danni." EDUCatt-Ente per il diritto allo studio universitario dell'Università Cattolica, 2014
Dataset of cumulative paid claims for a medium italian company in the line of business: motor third party liability.
sifa.mtplsifa.mtpl
Run-off triangle with 12 development periods.
Savelli, Nino, and Clemente, Gian Paolo. "Lezioni di matematica attuariale delle assicurazioni danni." EDUCatt-Ente per il diritto allo studio universitario dell'Università Cattolica, 2014